@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2012 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2014 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -50,9 +50,6 @@
 package com.openexchange.service.indexing.impl.internal.nonclustered;
 
 import java.util.Date;
-import java.util.concurrent.Callable;
-import java.util.concurrent.ExecutorService;
-import java.util.concurrent.FutureTask;
 import org.quartz.JobBuilder;
 import org.quartz.JobDetail;
 import org.quartz.JobKey;
@@ -62,19 +59,17 @@ import org.quartz.SimpleScheduleBuilder;
 import org.quartz.SimpleTrigger;
 import org.quartz.TriggerBuilder;
 import org.quartz.service.QuartzService;
-import com.hazelcast.core.DistributedTask;
 import com.hazelcast.core.HazelcastInstance;
+import com.hazelcast.core.IExecutorService;
 import com.openexchange.exception.OXException;
-import com.openexchange.index.IndexExceptionCodes;
 import com.openexchange.osgi.ExceptionUtils;
 import com.openexchange.service.indexing.IndexingService;
 import com.openexchange.service.indexing.JobInfo;
+import com.openexchange.service.indexing.impl.internal.JobConstants;
 import com.openexchange.service.indexing.impl.internal.SchedulerConfig;
 import com.openexchange.service.indexing.impl.internal.Services;
 import com.openexchange.service.indexing.impl.internal.Tools;
-import com.openexchange.threadpool.Task;
 import com.openexchange.threadpool.ThreadPoolService;
-import com.openexchange.threadpool.ThreadRenamer;
 
 /**
  * {@link IndexingServiceImpl}
@@ -180,13 +175,13 @@ public class IndexingServiceImpl implements IndexingService {
     public void scheduleJob(boolean async, final JobInfo info, final Date startDate, final long repeatInterval, final int priority) throws OXException {
         LOG.trace("Scheduling job {} at {} with interval {} and priority {}.", info, startDate == null ? "now" : startDate.toString(), repeatInterval, priority);
 
-        Task<Object> task = new TaskAdapter(new ScheduleJobCallable(info, startDate, repeatInterval, priority));
+        Runnable task = new ScheduleJobRunnable(info, startDate, repeatInterval, priority);
         try {
             if (async) {
                 ThreadPoolService threadPoolService = getThreadPoolService();
-                threadPoolService.submit(task);
+                threadPoolService.getExecutor().submit(task);
             } else {
-                call(task);
+                task.run();
             }
         } catch (Throwable t) {
             ExceptionUtils.handleThrowable(t);
@@ -194,36 +189,13 @@ public class IndexingServiceImpl implements IndexingService {
         }
     }
 
-    private <V> V call(final Task<V> task) throws OXException {
-        final Thread thread = Thread.currentThread();
-        boolean ran = false;
-        task.beforeExecute(thread);
-        try {
-            final V retval = task.call();
-            ran = true;
-            task.afterExecute(null);
-            return retval;
-        } catch (final Exception ex) {
-            if (!ran) {
-                task.afterExecute(ex);
-            }
-            // Else the exception occurred within
-            // afterExecute itself in which case we don't
-            // want to call it again.
-            throw (ex instanceof OXException ? (OXException) ex : IndexExceptionCodes.UNEXPECTED_ERROR.create(ex, ex.getMessage()));
-        }
-    }
-
     @Override
     public void unscheduleAllForUser(boolean async, int contextId, int userId) throws OXException {
         LOG.trace("Unscheduling all jobs for user {} in context {}.", userId, contextId);
 
         HazelcastInstance hazelcast = Services.getService(HazelcastInstance.class);
-        ExecutorService executorService = hazelcast.getExecutorService();
-        FutureTask<Object> task = new DistributedTask<Object>(
-            new UnscheduleAllJobsCallable(contextId, userId),
-            hazelcast.getCluster().getMembers());
-        executorService.submit(task);
+        IExecutorService executorService = hazelcast.getExecutorService(JobConstants.HZ_EXECUTOR);
+        executorService.executeOnAllMembers(new UnscheduleAllJobsRunnable(contextId, userId));
     }
 
     @Override
@@ -231,46 +203,12 @@ public class IndexingServiceImpl implements IndexingService {
         LOG.trace("Unscheduling all jobs for context {}.", contextId);
 
         HazelcastInstance hazelcast = Services.getService(HazelcastInstance.class);
-        ExecutorService executorService = hazelcast.getExecutorService();
-        FutureTask<Object> task = new DistributedTask<Object>(
-            new UnscheduleAllJobsCallable(contextId, -1),
-            hazelcast.getCluster().getMembers());
-        executorService.submit(task);
+        IExecutorService executorService = hazelcast.getExecutorService(JobConstants.HZ_EXECUTOR);
+        executorService.executeOnAllMembers(new UnscheduleAllJobsRunnable(contextId, -1));
     }
 
     ThreadPoolService getThreadPoolService() throws OXException {
         ThreadPoolService threadPoolService = Services.getService(ThreadPoolService.class);
         return threadPoolService;
     }
-
-    private static final class TaskAdapter implements Task<Object> {
-
-        private final Callable<Object> callable;
-
-        public TaskAdapter(Callable<Object> callable) {
-            super();
-            this.callable = callable;
-        }
-
-        @Override
-        public Object call() throws Exception {
-            return callable.call();
-        }
-
-        @Override
-        public void setThreadName(ThreadRenamer threadRenamer) {
-            return;
-        }
-
-        @Override
-        public void beforeExecute(Thread t) {
-            return;
-        }
-
-        @Override
-        public void afterExecute(Throwable t) {
-            return;
-        }
-
-    }
 }
