@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2012 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2014 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -103,4 +103,10 @@ public class SolrNodeListener implements MembershipListener {
         }
     }
 
+    /*-
+     * @Override
+    public void memberAttributeChanged(MemberAttributeEvent memberAttributeEvent) {
+        // Nothing to do
+    }*/
+
 }
